---
title: python-ufile
---

[![image](https://img.shields.io/pypi/v/python_ufile.svg)](https://pypi.python.org/pypi/python_ufile)

Python sdk for downloading/uploading to ufile.io both as a guest and
with an API key

-   Free software: MIT license
-   Documentation: <https://python-ufile.readthedocs.io>.

# Features

Upload files to ufile.io as a guest Download files from ufile.io with an
API_KEY Get file direct link from ufile.io with an API_KEY

# Credits

This package was coded in it\'s entirety by Aria Bagheri. Special thanks to ufile.io for providing the api endpoints. And also to all developers that put their blood, sweat, and tears into python, asyncio, and the requests library.